
# Type: imports


other schemas that are included in this schema

URI: [meta:imports](https://w3id.org/biolink/biolinkml/meta/imports)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>0..*</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
